//
//  CHBHPreBidSettings.h
//  HeliumSdk
//
//  Created by Kelly Dun on 3/24/22.
//

#import <Foundation/Foundation.h>

// Forward Swift declarations
typedef NS_ENUM(NSInteger, CHBHAdType);

NS_ASSUME_NONNULL_BEGIN

/// Settings used to pre-bid for the specified networks.
/// Pre-bidding is used by local bidding networks to run their auctions ahead of time to
/// send their bidding results to our auction server.
@interface CHBHPreBidSettings : NSObject

#pragma mark - Properties
/// Helium ad type associated with the pre-bid settings.
@property (nonatomic, assign, readonly) CHBHAdType heliumAdType;

/// Helium placement identifier.
@property (nonatomic, copy, readonly) NSString *heliumPlacement;

/// Network identifier that the pre-bid settings belong to.
@property (nonatomic, copy, readonly) NSString *networkIdentifier;

/// The network placement identifier.
@property (nonatomic, copy, readonly) NSString *networkPlacement;

/// Network-specific pre-bid settings.
@property (nonatomic, strong, readonly) NSDictionary *settings;

#pragma mark - Initialization

/// Initializes the pre-bid settings with the JSON entry.
/// @param json The `prebid` JSON entry which must contain the `partner_id` and `partner_placement` keys.
/// @param placement Helium placement identifier.
/// @param type Helium ad type.
/// @returns The initialized settings object if successful; otherwise @c nil if the required `partner_id` and `partner_placement` keys are missing.
- (nullable instancetype)initWithSettings:(NSDictionary *)json heliumPlacement:(NSString *)placement adType:(CHBHAdType)type NS_DESIGNATED_INITIALIZER;

#pragma mark - Unavailable Initializers

- (instancetype)init NS_UNAVAILABLE;
+ (instancetype)new NS_UNAVAILABLE;

#pragma mark - Dictionary Mapping

- (NSDictionary *)dictionaryRepresentation;

@end

NS_ASSUME_NONNULL_END
