//
//  NSError+HeliumErrors.h
//  HeliumSdk
//
//  Created by Kelly Dun on 3/25/22.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

/// Provides Helium-specific @c NSError objects to reduce boilerplate code.
@interface NSError (HeliumErrors)

/// An ad load is already in progress for the placement
/// @param placement The placement of the load attempt.
/// @returns An initialized @c NSError object.
+ (NSError *)heliumAdLoadAlreadyInProgressForPlacement:(NSString *)placement;

/// An interstitial ad load method was invoked on banner ad placement.
/// @returns An initialized @c NSError object.
+ (NSError *)heliumInvalidBannerLoadForPlacement:(NSString *)placement;

/// Placement identifier is empty or @c nil
/// @returns An initialized @c NSError object.
+ (NSError *)heliumInvalidPlacementIdentifier;

/// Failed to show a non-ready ad.
/// @returns An initialized @c NSError object.
+ (NSError *)heliumNoAdReadyToShow;

/// Failed to load a programmatic ad due to a missing bid payload.
/// @param placement The placement of the load attempt.
/// @returns An initialized @c NSError object.
+ (NSError *)heliumNoBidPayloadForPlacement:(NSString *)placement;

/// Non-programmatic load is not supported for the placement.
/// @param placement The placement of the load attempt.
/// @returns An initialized @c NSError object.
+ (NSError *)heliumNonProgrammaticLoadNotSupportedForPlacement:(NSString *)placement;

/// No pre-bid is available to load for the placement.
/// @param placement The placement of the load attempt.
/// @returns An initialized @c NSError object.
+ (NSError *)heliumNoPreBidReadyToLoadForPlacement:(NSString *)placement;

/// No view controller specified.
/// @returns An initialized @c NSError object.
+ (NSError *)heliumNoViewControllerSpecified;

/// The specified network's client adapter failed to initialize.
/// @param client Client class name.
/// @param parameter Required partner network SDK parameter that is missing.
/// @returns An initialized @c NSError object.
+ (NSError *)heliumPartnerClient:(NSString *)client failedInitializationWithMissingParameter:(NSString *)parameter;

/// The specified network's client adapter failed to initialize.
/// @param client Client class name.
/// @param reason Reason for failure.
/// @returns An initialized @c NSError object.
+ (NSError *)heliumPartnerClient:(NSString *)client failedInitializationWithReason:(NSString *)reason;

@end

NS_ASSUME_NONNULL_END
